@@ -5,9 +5,9 @@ Initial work and maintenance by Holger Brunn @hbrunn
 """
 
 import re
-import logging
+from logging import getLogger
 
-logger = logging.getLogger(__name__)
+logger = getLogger(__name__)
 
 DEFAULT_OPTIONS = {"line_separator": r"\n"}
 
@@ -23,8 +23,14 @@ def parse_line(patterns, line):
 
 def parse_block(template, field, settings, content):
     # Validate settings
-    assert "line" in settings, "Line regex missing"
+    assert "line" in settings, (
+        "Error in Template %s Line regex missing" % template["template_name"]
+    )
 
+    logger.debug(
+        "START lines block content ========================\n%s", content
+    )
+    logger.debug("END lines block content ==========================")
     lines = []
     current_row = {}
 
@@ -91,7 +97,7 @@ def parse_block(template, field, settings, content):
                     skip_line_results = [re.search(settings["skip_line"], line)]
                 if any(skip_line_results):
                     # There was at least one match to a skip_line
-                    logger.debug("skip_line match on *%s*", line)
+                    logger.debug("skip_line match on \ns*%s*", line)
                     continue
             # If none of those have continued the loop, check if this is just a normal line
             match = parse_line(settings["line"], line)
@@ -101,7 +107,7 @@ def parse_block(template, field, settings, content):
                 current_row = parse_current_row(match, current_row)
                 continue
         # If the line doesn't match anything, log and continue to next line
-        logger.debug("ignoring *%s* because it doesn't match anything", line)
+        logger.debug("The following line doesn't match anything:\n*%s*", line)
     if current_row:
         # All lines processed, so append whatever the final current_row was to output
         lines.append(current_row)
@@ -115,14 +121,18 @@ def parse_block(template, field, settings, content):
     return lines
 
 
-def parse(template, field, _settings, content):
+def parse_by_rule(template, field, rule, content):
     # First apply default options.
     settings = DEFAULT_OPTIONS.copy()
-    settings.update(_settings)
+    settings.update(rule)
 
     # Validate settings
-    assert "start" in settings, "Lines start regex missing"
-    assert "end" in settings, "Lines end regex missing"
+    assert "start" in settings, (
+        "Error in Template %s Lines start regex missing" % template["template_name"]
+    )
+    assert "end" in settings, (
+        "Error in Template %s Lines end regex missing" % template["template_name"]
+    )
 
     blocks_count = 0
     lines = []
@@ -131,12 +141,13 @@ def parse(template, field, _settings, content):
     while True:
         start = re.search(settings["start"], content)
         if not start:
+            logger.debug("Failed to find lines block start")
             break
         content = content[start.end():]
 
         end = re.search(settings["end"], content)
         if not end:
-            logger.warning("Failed to find lines block end")
+            logger.debug("Failed to find lines block end")
             break
 
         blocks_count += 1
@@ -152,6 +163,25 @@ def parse(template, field, _settings, content):
     return lines
 
 
+def parse(template, field, settings, content):
+    if "rules" in settings:
+        # One field can have multiple sets of line-parsing rules
+        rules = settings['rules']
+    else:
+        # Original syntax stored line-parsing rules in top field YAML object
+        keys = ('start', 'end', 'line', 'first_line', 'last_line', 'skip_line', 'types')
+        rules = [{k: v for k, v in settings.items() if k in keys}]
+
+    lines = []
+    for i, rule in enumerate(rules):
+        logger.debug("Testing Rules set #%s", i)
+        new_lines = parse_by_rule(template, field, rule, content)
+        if new_lines is not None:
+            lines += new_lines
+
+    return lines
+
+
 def parse_current_row(match, current_row):
     # Parse the current row data
     for field, value in match.groupdict().items():
