@@ -2,4 +2,4 @@
 
 def to_text(path):
     with open(path, 'r') as f:
-        return f.read().encode('utf-8')
+        return f.read()
